@@ -38,7 +38,7 @@
 
 package UMLS::Similarity;
 
-$VERSION = '1.11';
+$VERSION = '1.13';
 
 sub new
 {
@@ -73,8 +73,6 @@ module to access the UMLS present in a mysql database.
 
 =head1 SYNOPSIS
 
- #!/usr/bin/perl
-
  use UMLS::Interface;
  use UMLS::Similarity::lch;
  use UMLS::Similarity::path;
@@ -91,11 +89,11 @@ module to access the UMLS present in a mysql database.
  my $cui1 = "C0005767";
  my $cui2 = "C0007634";
 
- @ts1 = $umls->getTermList($cui1);
- my $term1 = pop @ts1;
+ $ts1 = $umls->getTermList($cui1);
+ my $term1 = pop @{$ts1};
 
- @ts2 = $umls->getTermList($cui2);
- my $term2 = pop @ts2;
+ $ts2 = $umls->getTermList($cui2);
+ my $term2 = pop @{$ts2};
 
  my $lvalue = $lch->getRelatedness($cui1, $cui2);
 
