@@ -297,19 +297,19 @@ sub getRelatedness
 		$defs1 = $interface->getExtendedDefinition($cui1);
 		$term1_def = $dictionary{$term1} if (defined $dictionary{$term1});
 
-=comment
-		# check the cui's associated term's def in dictfile
-		@dictfile_term1 = $interface->getTermList($cui1);		
-		foreach my $t (@dictfile_term1)
-		{
-			if(defined ($dictionary{$t}))
-			{
-				my $term1_def = $dictionary{$t};
-				$def1 .= "$term1_def" . " ";
-			}	
-		}
-=cut
 
+		# check the cui's associated term's def in dictfile
+		#@dictfile_term1 = $interface->getTermList($cui1);		
+		#foreach my $t (@dictfile_term1)
+		#{
+			#if(defined ($dictionary{$t}))
+			#{
+				#my $term1_def = $dictionary{$t};
+				#$def1 .= "$term1_def" . " ";
+			#}	
+		#}
+
+  
 	}
 	else
 	{
@@ -330,18 +330,17 @@ sub getRelatedness
 		$defs2 = $interface->getExtendedDefinition($cui2);
 		$term2_def = $dictionary{$term2} if (defined $dictionary{$term2});
 
-=comment
+
 		# check the cui's associated term's def in dictfile
-		@dictfile_term2 = $interface->getTermList($cui2);		
-		foreach my $t (@dictfile_term2)
-		{
-			if(defined ($dictionary{$t}))
-			{
-				my $term2_def = $dictionary{$t};
-				$def2 .= "$term2_def" . " ";
-			}	
-		}
-=cut
+		#@dictfile_term2 = $interface->getTermList($cui2);		
+		#foreach my $t (@dictfile_term2)
+		#{
+			#if(defined ($dictionary{$t}))
+			#{
+				#my $term2_def = $dictionary{$t};
+				#$def2 .= "$term2_def" . " ";
+			#}	
+		#}
 
 	}
 	else
